<?php

return[
    'newsletter_info' => [
        'label'        => 'Newsletter',
        'file'         => __DIR__ . '/../docs/newsletter.md',
        'position'     => 100,
        'acl_resource' => 'newsletter',
        'acl_action'   => 'view_newsletter',
        'uri'          => 'newsletter_info',
        'pages'        => [
            'nl_emails'    => [
                'label'    => 'Emails',
                'file'     => __DIR__ . '/../docs/emails.md',
                'position' => 10,
                'uri'      => 'newsletter/email',
            ],
            'nl_messages'  => [
                'label'    => 'Messages',
                'file'     => __DIR__ . '/../docs/message.md',
                'position' => 20,
                'uri'      => 'newsletter/message',
            ],
            'nl_mailchimp' => [
                'label'    => 'MailChimp',
                'file'     => __DIR__ . '/../docs/mailchimp.md',
                'position' => 30,
                'uri'      => 'newsletter/mail_chimp',
            ]
        ]
    ]
];
