<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['upgrade_newsletter'] = [
    [
        'version' => '0',
        'library' => 'newsletter/migrations/newsletter_upgrade_0',
    ],
    [
        'version' => '1.1.0',
        'library' => 'newsletter/migrations/newsletter_upgrade_1_1_0',
    ],
    [
        'version' => '3.0.1',
        'library' => 'newsletter/migrations/newsletter_upgrade_3_0_1',
    ],
];
